# Versions

## 1.0.0

Add:

* Docx template engine (`template_engines.backends.docx.DocxEngine`).
* Docx template class (`template_engines.backends.odt.DocxTemplate`).


## 0.0.4

* Abstract template engine for writing custom engines (`template_engines.backends.abstract.AbstractEngine`).
* Abstract template class for writing custom template classes (`template_engines.backends.abstract.AbstractTemplate`).
* Odt template engine (`template_engines.backends.odt.OdtEngine`).
* Odt template class (`template_engines.backends.odt.OdtTemplate`).
* A template tag to load images into an odt template (`odt_image_loader`).
